@@ -28,17 +28,18 @@ main(int argc,
      char **argv)
 {
     XfconfChannel *channel;
-    
-    if(!xfconf_tests_start())
+
+    if (!xfconf_tests_start()) {
         return 1;
-    
+    }
+
     channel = xfconf_channel_new(TEST_CHANNEL_NAME);
-    
+
     TEST_OPERATION(xfconf_channel_get_uint64(channel, test_uint64_property, -1) == test_uint64);
-    
+
     g_object_unref(G_OBJECT(channel));
-    
+
     xfconf_tests_end();
-    
+
     return 0;
 }
